Installation · Chart.js documentation
Author: chartjs

# Installation

Chart.js can be installed via npm or bower. It is recommended to get Chart.js this way.

## npm

    npm install chart.js --save

## Bower

    bower install chart.js --save

## CDN

### CDNJS

Chart.js built files are available on CDNJS:

https://cdnjs.com/libraries/Chart.js

### jsDelivr

Chart.js built files are also available through jsDelivr:

https://www.jsdelivr.com/package/npm/chart.js?path=dist

## Github

You can download the latest version of Chart.js on GitHub.

If you download or clone the repository, you must build Chart.js to generate the dist files. Chart.js no longer comes with prebuilt release versions, so an alternative option to downloading the repo is strongly advised.

# Selecting the Correct Build

Chart.js provides two different builds for you to choose: `Stand-Alone Build`, `Bundled Build`.

## Stand-Alone Build

Files:

- `dist/Chart.js`
- `dist/Chart.min.js`

The stand-alone build includes Chart.js as well as the color parsing library. If this version is used, you are required to include Moment.js before Chart.js for the functionality of the time axis.

## Bundled Build

Files:

- `dist/Chart.bundle.js`
- `dist/Chart.bundle.min.js`

The bundled build includes Moment.js in a single file. You should use this version if you require time axes and want to include a single file. You should not use this build if your application already included Moment.js. Otherwise, Moment.js will be included twice which results in increasing page load time and possible version compatability issues.

# results matching ""

# No results matching ""